@@ -368,7 +368,6 @@ get_session_id_for_user_on_seat_consolekit (GDBusConnection  *connection,
                                             GError          **error)
 {
         GVariant       *reply;
-        GVariant       *array;
         const gchar   **sessions;
         char           *session = NULL;
         struct passwd  *pwent;
@@ -401,13 +400,15 @@ get_session_id_for_user_on_seat_consolekit (GDBusConnection  *connection,
                                              NULL,
                                              error);
         if (reply == NULL) {
+                g_set_error (error,
+                             G_DBUS_ERROR,
+                             G_DBUS_ERROR_ACCESS_DENIED,
+                             _("Unable to find session for user %s"),
+                             username);
                 return NULL;
         }
 
-        g_variant_get (reply, "(ao)", &array);
-
-        sessions = g_variant_get_objv (array, NULL);
-
+        g_variant_get_child (reply, 0, "^a&o", &sessions);
         for (i = 0; sessions[i] != NULL; i++) {
                 GVariant *reply2;
                 GError   *error2 = NULL;
@@ -429,7 +430,7 @@ get_session_id_for_user_on_seat_consolekit (GDBusConnection  *connection,
                         continue;
                 }
 
-                g_variant_get (reply, "(o)", &session_seat_id);
+                g_variant_get (reply2, "(o)", &session_seat_id);
                 g_variant_unref (reply2);
 
                 if (g_strcmp0 (seat, session_seat_id) != 0) {
@@ -468,6 +469,13 @@ get_session_id_for_user_on_seat_consolekit (GDBusConnection  *connection,
         g_free (sessions);
         g_variant_unref (reply);
 
+        if (session == NULL) {
+                g_set_error (error,
+                             G_DBUS_ERROR,
+                             G_DBUS_ERROR_ACCESS_DENIED,
+                             _("Unable to find appropriate session for user %s"),
+                             username);
+        }
         return session;
 }
 #endif
