@@ -14,7 +14,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
  */
 
@@ -43,6 +43,7 @@ typedef struct GdmXdmcpChooserDisplayPrivate GdmXdmcpChooserDisplayPrivate;
 typedef struct
 {
         GdmXdmcpDisplay                parent;
+        GdmXdmcpChooserDisplayPrivate *priv;
 } GdmXdmcpChooserDisplay;
 
 typedef struct
