@@ -196,7 +196,7 @@ set_busy (GdmGreeterLoginWindow *login_window)
 
         cursor = gdk_cursor_new (GDK_WATCH);
         gdk_window_set_cursor (gtk_widget_get_window (GTK_WIDGET (login_window)), cursor);
-        gdk_cursor_unref (cursor);
+        g_object_unref (cursor);
 }
 
 static void
